"use strict";

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

var fs = require('fs');

var path = require('path');

var Module = require('module');

var _require = require('util'),
    promisify = _require.promisify;

var RSS = require('rss');

var g = require('glob');

var mdx = require('@mdx-js/mdx');

var babel = require('@babel/core');

var glob = promisify(g);

function requireFromStringSync(src, filename) {
  var m = new Module();

  m._compile(src, filename);

  return m.exports;
}

function requireMDXSync(mdxSrc, filename) {
  var jsx = mdx.sync(mdxSrc);
  var transformed = babel.transformSync(jsx, {
    babelrc: false,
    presets: ['@babel/preset-react'],
    plugins: ['@babel/plugin-transform-modules-commonjs', '@babel/plugin-proposal-object-rest-spread']
  });
  return requireFromStringSync(transformed.code, filename);
}

function requireMDXFileSync(path) {
  var mdxSrc = fs.readFileSync(path, {
    encoding: 'utf-8'
  });
  return requireMDXSync(mdxSrc, path);
}

function readPostMetadata(filePath) {
  var mod = requireMDXFileSync(filePath);
  var meta = mod.meta;
  return {
    filePath: filePath,
    urlPath: filePath.replace(/\\/, '/').replace(/^pages/, '').replace(/\.mdx?$/, ''),
    title: meta.title || path.basename(filePath),
    publishDate: new Date(meta.publishDate)
  };
}

function generateRSS(posts) {
  var siteUrl = 'https://hipstersmoothie.com';
  var feed = new RSS({
    title: "Andrew Lisowski's blog",
    // eslint-disable-next-line camelcase
    site_url: siteUrl
  });
  posts.forEach(function (post) {
    feed.item({
      title: post.title,
      guid: post.urlPath,
      url: siteUrl + post.urlPath,
      date: post.publishDate
    });
  });
  return feed.xml({
    indent: true
  });
}

module.exports =
/*#__PURE__*/
function () {
  var _ref = _asyncToGenerator(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(options) {
    var postPaths, now, posts, postsJSON, exportPath, rssPath, rssXML;
    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.next = 2;
            return glob('pages/**/*.mdx');

          case 2:
            postPaths = _context.sent;
            now = new Date();
            posts = postPaths.map(readPostMetadata).map(function (post) {
              post.author = post.author || options.author;
              post.authorLink = post.authorLink || options.authorLink;
              post.avatar = post.avatar || options.avatar;
              post.urlPath = path.join(options.assetPrefix || '/', post.urlPath);
              return post;
            }).filter(function (post) {
              return post.publishDate <= now;
            }).sort(function (a, b) {
              return b.publishDate - a.publishDate;
            });
            postsJSON = JSON.stringify(posts, null, 2);
            exportPath = 'posts.js';
            fs.writeFileSync(exportPath, '// automatically generated by build_post_index.js\n' + "export default ".concat(postsJSON, "\n"));
            console.info("Saved ".concat(posts.length, " posts in ").concat(exportPath));
            rssPath = 'static/rss-feed.xml';
            rssXML = generateRSS(posts);
            fs.writeFileSync(rssPath, rssXML);
            console.info("Saved RSS feed to ".concat(rssPath));

          case 13:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function (_x) {
    return _ref.apply(this, arguments);
  };
}();